@@ -126,6 +126,7 @@ def generate(
     custom_template_dir: Optional[str] = None,
     extra_template_data: Optional[DefaultDict[str, Dict[str, Any]]] = None,
     validation: bool = False,
+    field_constraints: bool = False,
 ) -> None:
     if input_file_type == InputFileType.Auto:
         try:
@@ -173,6 +174,7 @@ def generate(
         text=input_text,
         dump_resolve_reference_action=dump_resolve_reference_action,
         validation=validation,
+        field_constraints=field_constraints,
     )
 
     with chdir(output):
