@@ -18,6 +18,9 @@ class Import(BaseModel):
 
 
 class Imports(DefaultDict[Optional[str], Set[str]]):
+    def __str__(self) -> str:
+        return self.dump()
+
     def __init__(self) -> None:
         super().__init__(set)
         self.alias: DefaultDict[Optional[str], Dict[str, str]] = defaultdict(dict)
