@@ -1,5 +1,5 @@
 #!/usr/bin/env bash
 set -e
 
-black datamodel_code_generator tests --skip-string-normalization
+black datamodel_code_generator tests
 isort --recursive datamodel_code_generator tests
